# apswapi.py
# Copyright 2015 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""Object database using apsw, an alternative Python Sqlite3 wrapper.  A
repr(object) is held on the database, recoverable by the ast.literal_eval()
method.   Indicies whose values are derived from the object are supported.
"""

import apsw

from ._sqlite import (
    Sqlite3apiError, # For the benefit of subclasses of Sqlite3base.
    Sqlite3base,
    Sqlite3api,
    Sqlite3Primary,
    Sqlite3Secondary,
    )


class Sqlite3base(Sqlite3base):
    
    """Define a Berkeley DB-like database structure using apsw.

    This class contains methods peculiar to using the apsw package.
    """

    def make_connection(self):
        """Open Sqlite database with apsw module."""
        if self._sqconn is None:
            self._sqconn = apsw.Connection(self._home)
            # Remove the following statement to convert to unicode strings
            #self._sqconn.text_factory = str


class Sqlite3api(Sqlite3api, Sqlite3base):
    
    """Define a Berkeley DB-like database structure using apsw."""

    def __init__(self, database_specification, *args, **kargs):
        """Define database structure.  See Sqlite3base's superclass for *args
        and **kargs.
        """
        super().__init__(
            Sqlite3Primary,
            Sqlite3Secondary,
            database_specification,
            *args,
            **kargs)
