# apswduapi.py
# Copyright (c) 2015 Roger Marsh
# Licence: See LICENCE (BSD licence)

"""Provide sqlite3 database access methods compatible with DPT single-step.

The compatibility provided is doing large updates in a separate process.

The sqlite3 equivalent to any form of DPT deferred update is drop indexes
before the update and create the indexes after the update.

See www.dptoolkit.com for details of DPT

"""

from .apswapi import (
    Sqlite3base,
    )
from ._sqlitedu import (
    Sqlite3duapi,
    Sqlite3duPrimary,
    Sqlite3duSecondary,
    Sqlite3duapiError, # For the benefit of subclasses of Sqlite3base.
    )


class Sqlite3duapi(Sqlite3duapi, Sqlite3base):
    
    """Support sqlite3 equivalent for DPT single-step deferred updates.

    Extend and override Sqlite3base methods for update.
    
    """

    def __init__(self, database_specification, *args, **kargs):
        """Define database structure.  See superclass for *args and **kargs."""
        super(Sqlite3duapi, self).__init__(
            Sqlite3duPrimary,
            Sqlite3duSecondary,
            database_specification,
            *args,
            **kargs)
